@@ -5,10 +5,7 @@ import swem
 from gensim.models import KeyedVectors
 
 if __name__ == '__main__':
-    # kv: KeyedVectors = KeyedVectors(vector_size=200)
-    kv = {
-        'I': np.zeros(200),
-    }
+    kv: KeyedVectors = KeyedVectors(vector_size=200)
     tokens: List[str] = ['I', 'have', 'a', 'pen']
 
     embed: np.ndarray = swem.infer_vector(
